[FFmpeg-cvslog] dirac_dwt: Make x86 files/functions names consistent

Timothy Gu git at videolan.org
Sat Feb 6 04:32:07 CET 2016


ffmpeg | branch: master | Timothy Gu <timothygu99 at gmail.com> | Wed Feb  3 00:21:46 2016 +0000| [9fd6ea933fa107884230dce98dffa4ba166fa93d] | committer: Timothy Gu

dirac_dwt: Make x86 files/functions names consistent

> http://git.videolan.org/gitweb.cgi/ffmpeg.git/?a=commit;h=9fd6ea933fa107884230dce98dffa4ba166fa93d
---

 libavcodec/dirac_dwt.c                           |    5 ++--
 libavcodec/dirac_dwt.h                           |    1 +
 libavcodec/x86/Makefile                          |    6 ++---
 libavcodec/x86/{dwt_yasm.asm => dirac_dwt.asm}   |    2 +-
 libavcodec/x86/dirac_dwt.h                       |   30 ----------------------
 libavcodec/x86/{dirac_dwt.c => dirac_dwt_init.c} |    6 ++---
 6 files changed, 10 insertions(+), 40 deletions(-)

diff --git a/libavcodec/dirac_dwt.c b/libavcodec/dirac_dwt.c
index 9d74e3b..732615c 100644
--- a/libavcodec/dirac_dwt.c
+++ b/libavcodec/dirac_dwt.c
@@ -23,7 +23,6 @@
 #include "libavutil/avassert.h"
 #include "libavutil/common.h"
 #include "dirac_dwt.h"
-#include "libavcodec/x86/dirac_dwt.h"
 
 #define TEMPLATE_8bit
 #include "dirac_dwt_template.c"
@@ -54,8 +53,8 @@ int ff_spatial_idwt_init2(DWTContext *d, uint8_t *buffer, int width, int height,
         return AVERROR_INVALIDDATA;
     }
 
-    if (HAVE_MMX && bit_depth == 8)
-        ff_spatial_idwt_init_mmx(d, type);
+    if (ARCH_X86 && bit_depth == 8)
+        ff_spatial_idwt_init_x86(d, type);
     return 0;
 }
 
diff --git a/libavcodec/dirac_dwt.h b/libavcodec/dirac_dwt.h
index 41842b5..b3be596 100644
--- a/libavcodec/dirac_dwt.h
+++ b/libavcodec/dirac_dwt.h
@@ -79,6 +79,7 @@ enum dwt_type {
 int ff_spatial_idwt_init2(DWTContext *d, uint8_t *buffer, int width, int height,
                           int stride, enum dwt_type type, int decomposition_count,
                           uint8_t *temp, int bit_depth);
+void ff_spatial_idwt_init_x86(DWTContext *d, enum dwt_type type);
 
 void ff_spatial_idwt_slice2(DWTContext *d, int y);
 
diff --git a/libavcodec/x86/Makefile b/libavcodec/x86/Makefile
index 1baec49..bfdf0b3 100644
--- a/libavcodec/x86/Makefile
+++ b/libavcodec/x86/Makefile
@@ -6,7 +6,8 @@ OBJS-$(CONFIG_AUDIODSP)                += x86/audiodsp_init.o
 OBJS-$(CONFIG_BLOCKDSP)                += x86/blockdsp_init.o
 OBJS-$(CONFIG_BSWAPDSP)                += x86/bswapdsp_init.o
 OBJS-$(CONFIG_DCT)                     += x86/dct_init.o
-OBJS-$(CONFIG_DIRAC_DECODER)           += x86/diracdsp_init.o
+OBJS-$(CONFIG_DIRAC_DECODER)           += x86/diracdsp_init.o           \
+                                          x86/dirac_dwt_init.o
 OBJS-$(CONFIG_FDCTDSP)                 += x86/fdctdsp_init.o
 OBJS-$(CONFIG_FFT)                     += x86/fft_init.o
 OBJS-$(CONFIG_FLACDSP)                 += x86/flacdsp_init.o
@@ -73,7 +74,6 @@ OBJS-$(CONFIG_WEBP_DECODER)            += x86/vp8dsp_init.o
 
 # GCC inline assembly optimizations
 # subsystems
-MMX-OBJS-$(CONFIG_DIRAC_DECODER)       += x86/dirac_dwt.o
 MMX-OBJS-$(CONFIG_FDCTDSP)             += x86/fdct.o
 MMX-OBJS-$(CONFIG_IDCTDSP)             += x86/simple_idct.o
 
@@ -135,7 +135,7 @@ YASM-OBJS-$(CONFIG_ALAC_DECODER)       += x86/alacdsp.o
 YASM-OBJS-$(CONFIG_APNG_DECODER)       += x86/pngdsp.o
 YASM-OBJS-$(CONFIG_DCA_DECODER)        += x86/synth_filter.o
 YASM-OBJS-$(CONFIG_DIRAC_DECODER)      += x86/diracdsp.o                \
-                                          x86/dwt_yasm.o
+                                          x86/dirac_dwt.o
 YASM-OBJS-$(CONFIG_DNXHD_ENCODER)      += x86/dnxhdenc.o
 YASM-OBJS-$(CONFIG_FLAC_DECODER)       += x86/flacdsp.o
 ifdef CONFIG_GPL
diff --git a/libavcodec/x86/dwt_yasm.asm b/libavcodec/x86/dirac_dwt.asm
similarity index 99%
rename from libavcodec/x86/dwt_yasm.asm
rename to libavcodec/x86/dirac_dwt.asm
index 658acc1..8980689 100644
--- a/libavcodec/x86/dwt_yasm.asm
+++ b/libavcodec/x86/dirac_dwt.asm
@@ -1,5 +1,5 @@
 ;******************************************************************************
-;* MMX optimized discrete wavelet trasnform
+;* x86 optimized discrete wavelet trasnform
 ;* Copyright (c) 2010 David Conrad
 ;*
 ;* This file is part of FFmpeg.
diff --git a/libavcodec/x86/dirac_dwt.h b/libavcodec/x86/dirac_dwt.h
deleted file mode 100644
index 126b290..0000000
--- a/libavcodec/x86/dirac_dwt.h
+++ /dev/null
@@ -1,30 +0,0 @@
-/*
- * This file is part of FFmpeg.
- *
- * FFmpeg is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * FFmpeg is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with FFmpeg; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
- */
-
-#ifndef AVCODEC_X86_DIRAC_DWT_H
-#define AVCODEC_X86_DIRAC_DWT_H
-
-#include "libavcodec/dirac_dwt.h"
-
-void ff_horizontal_compose_dd97i_end_c(IDWTELEM *b, IDWTELEM *tmp, int w2, int x);
-void ff_horizontal_compose_haar1i_end_c(IDWTELEM *b, IDWTELEM *tmp, int w2, int x);
-void ff_horizontal_compose_haar0i_end_c(IDWTELEM *b, IDWTELEM *tmp, int w2, int x);
-
-void ff_spatial_idwt_init_mmx(DWTContext *d, enum dwt_type type);
-
-#endif
diff --git a/libavcodec/x86/dirac_dwt.c b/libavcodec/x86/dirac_dwt_init.c
similarity index 98%
rename from libavcodec/x86/dirac_dwt.c
rename to libavcodec/x86/dirac_dwt_init.c
index c9c7093..afdf0a1 100644
--- a/libavcodec/x86/dirac_dwt.c
+++ b/libavcodec/x86/dirac_dwt_init.c
@@ -1,5 +1,5 @@
 /*
  * MMX optimized discrete wavelet transform
  * Copyright (c) 2002-2004 Michael Niedermayer <michaelni at gmx.at>
  * Copyright (c) 2010 David Conrad
  *
@@ -22,7 +22,7 @@
 
 #include "libavutil/x86/asm.h"
 #include "libavutil/x86/cpu.h"
-#include "dirac_dwt.h"
+#include "libavcodec/dirac_dwt.h"
 
 #define COMPOSE_VERTICAL(ext, align) \
 void ff_vertical_compose53iL0##ext(int16_t *b0, int16_t *b1, int16_t *b2, int width); \
@@ -158,7 +158,7 @@ static void horizontal_compose_dd97i_ssse3(uint8_t *_b, uint8_t *_tmp, int w)
 }
 #endif
 
-void ff_spatial_idwt_init_mmx(DWTContext *d, enum dwt_type type)
+void ff_spatial_idwt_init_x86(DWTContext *d, enum dwt_type type)
 {
 #if HAVE_YASM
   int mm_flags = av_get_cpu_flags();
@@ -1,5 +1,5 @@
 /*
- * MMX optimized discrete wavelet transform
+ * x86 optimized discrete wavelet transform
  * Copyright (c) 2002-2004 Michael Niedermayer <michaelni at gmx.at>
  * Copyright (c) 2010 David Conrad



More information about the ffmpeg-cvslog mailing list